Crate workspacer_show

Structs

ShowFlags
Extended ShowFlags with a new show_items_with_no_data flag. If show_items_with_no_data is true, we’ll display placeholders:
ShowFlagsBuilder
Builder for ShowFlags.

Enums

ShowFlagsBuilderError
Error type for ShowFlagsBuilder

Traits

ShowAll
ShowItem
A trait for showing info about a single crate (which may also merge in its dependencies if configured).

Functions

join_with_blank_line
Joins a list of strings with a blank line separating them.
show_crate
Subroutine for handling ws show crate subcommand: single crate only. We do not attempt to create a workspace. We simply confirm that the given path is a single crate.
show_crate_tree
Subroutine for handling ws show crate-tree subcommand: single crate plus its internal dependencies. If merge_crates is true, merges them into one interface; otherwise prints them separately with dividers.
show_workspace
Subroutine for handling ws show workspace subcommand: multiple crates in a workspace. Prints each crate individually with a divider line.